==> phantomjs_1.3.0+dfsg.orig.tar.gz: phantomjs-1.3.0+dfsg/README.md <==
PhantomJS ([www.phantomjs.org](http://phantomjs.org)) is a headless WebKit with JavaScript API.

It has **fast** and **native** support for DOM handling, CSS selector, JSON, Canvas, and SVG.

PhantomJS is cross-platform, it can be compiled for Linux, Windows, FreeBSD, and Mac OS X.
Refer to the [build instructions](http://code.google.com/p/phantomjs/wiki/BuildInstructions)
for details.

**Note**: If you are on Mac OS X, [read the notice](http://code.google.com/p/phantomjs/wiki/BuildInstructions#Mac_OS_X)
before you start using `brew` or `port` to install Qt and/or PhantomJS.

PhantomJS scripts can be written in JavaScript or [CoffeeScript](http://jashkenas.github.com/coffee-script/).

See also [quick start guide](http://code.google.com/p/phantomjs/wiki/QuickStart)
and more [advanced examples](http://code.google.com/p/phantomjs/wiki/ServiceIntegration)
which show various PhantomJS scripts, covering:

* getting driving direction
* showing weather forecast conditions
* finding pizza in New York
* looking up approximate location based on IP address
* pulling the list of seasonal food
* running regression tests from command line
* producing PDF version of a Wikipedia article
* rasterizing SVG to image

Do not forget to consult the concise [API Reference](http://code.google.com/p/phantomjs/wiki/Interface).

PhantomJS is based on [Qt](http://qt.nokia.com). There are two implementations, using C++ and Python.

The last [stable release](http://code.google.com/p/phantomjs/wiki/ReleaseNotes) is version 1.3 ("Water Lily").

If you want to contribute, please read the [Contribution Guide](http://code.google.com/p/phantomjs/wiki/ContributionGuide).

==> phantomjs_1.4.0+dfsg.orig.tar.gz: phantomjs-1.4.0+dfsg/README.md <==
PhantomJS ([www.phantomjs.org](http://phantomjs.org)) is a headless WebKit with JavaScript API.

It has **fast** and **native** support for DOM handling, CSS selector, JSON, Canvas, and SVG.

PhantomJS is cross-platform, it can be compiled for Linux, Windows, FreeBSD, and Mac OS X.
Refer to the [build instructions](http://code.google.com/p/phantomjs/wiki/BuildInstructions)
for details.

**Note**: If you are on Mac OS X, [read the notice](http://code.google.com/p/phantomjs/wiki/BuildInstructions#Mac_OS_X)
before you start using `brew` or `port` to install Qt and/or PhantomJS.

PhantomJS scripts can be written in JavaScript or [CoffeeScript](http://jashkenas.github.com/coffee-script/).

See also [quick start guide](http://code.google.com/p/phantomjs/wiki/QuickStart)
and more [advanced examples](http://code.google.com/p/phantomjs/wiki/ServiceIntegration)
which show various PhantomJS scripts, covering:

* getting driving direction
* showing weather forecast conditions
* finding pizza in New York
* looking up approximate location based on IP address
* pulling the list of seasonal food
* running regression tests from command line
* producing PDF version of a Wikipedia article
* rasterizing SVG to image

Do not forget to consult the concise [API Reference](http://code.google.com/p/phantomjs/wiki/Interface).

PhantomJS is based on [Qt](http://qt.nokia.com). There are two implementations, using C++ and Python.

The latest [stable release](http://code.google.com/p/phantomjs/wiki/ReleaseNotes) is version 1.4 ("Glory of the Snow").

If you want to contribute, please read the [Contribution Guide](http://code.google.com/p/phantomjs/wiki/ContributionGuide).
